@@ -40,8 +40,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman@xael.org)'
-__version__ = '0.4.1'
-__last_modification__ = '2015.08.21'
+__version__ = '0.4.2'
+__last_modification__ = '2015.09.11'
 
 
 import collections
@@ -97,7 +97,11 @@ class PortScanner(object):
         # This is for Mac OSX. When idle3 is launched from the finder, PATH is not set so nmap was not found
         for nmap_path in nmap_search_path:
             try:
-                p = subprocess.Popen([nmap_path, '-V'], bufsize=10000, stdout=subprocess.PIPE, close_fds=True)
+                if sys.platform.startswith('freebsd') or sys.platform.startswith('linux') or sys.platform.startswith('darwin'):
+                    p = subprocess.Popen([nmap_path, '-V'], bufsize=10000, stdout=subprocess.PIPE, close_fds=True)
+                else:
+                    p = subprocess.Popen([nmap_path, '-V'], bufsize=10000, stdout=subprocess.PIPE)
+                    
             except OSError:
                 pass
             else:
@@ -827,7 +831,10 @@ class PortScannerHostDict(dict):
             if h['type'] == 'user':
                 return h['name']
         else:
-            return self['hostnames'][0]['name']
+            if len(self['hostnames']) > 0 and 'name' in self['hostnames']:
+                return self['hostnames'][0]['name']
+            else:
+                return ''
 
         return hostname
 
